@@ -7,11 +7,12 @@
 /*                                                             */
 /*  This file is part of REMIND.                               */
 /*  Copyright (C) 1992-1998 by David F. Skoll                  */
+/*  Copyright (C) 1999-2000 by Roaring Penguin Software Inc.   */
 /*                                                             */
 /***************************************************************/
 
 static char const RCSID[] =
-"$Id: dynbuf.c,v 1.2 1998/02/10 03:15:48 dfs Exp $";
+"$Id: dynbuf.c,v 1.5 2000/02/18 03:45:49 dfs Exp $";
 
 #include "config.h"
 #include "dynbuf.h"
@@ -181,7 +182,7 @@ PUBLIC int DBufGets(DynamicBuffer *dbuf, FILE *fp)
 #else
 int DBufGets(dbuf, fp)
 DynamicBuffer *dbuf;
-FILE *fp
+FILE *fp;
 #endif
 {
     char tmp[256]; /* Safe to hard-code */
